==> node-espree_7.3.1~dfsg1.orig.tar.xz: espree-7.3.1/tests/fixtures/ecma-version/9/regexp-unicode-property-escape/valid-negative-2.result.js <==
const conditionalRegex = require("../../../../lib/conditional-regex-value");

module.exports = {
    "type": "Program",
    "loc": {
        "start": {
            "line": 1,
            "column": 0
        },
        "end": {
            "line": 1,
            "column": 22
        }
    },
    "range": [
        0,
        22
    ],
    "body": [
        {
            "type": "ExpressionStatement",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 1,
                    "column": 22
                }
            },
            "range": [
                0,
                22
            ],
            "expression": conditionalRegex({
                "type": "Literal",
                "loc": {
                    "start": {
                        "line": 1,
                        "column": 0
                    },
                    "end": {
                        "line": 1,
                        "column": 22
                    }
                },
                "range": [
                    0,
                    22
                ],
                "value": null,
                "raw": "/\\P{Script=Hiragana}/u",
                "regex": {
                    "pattern": "\\P{Script=Hiragana}",
                    "flags": "u"
                }
            })
        }
    ],
    "sourceType": "script",
    "tokens": [
        {
            "type": "RegularExpression",
            "value": "/\\P{Script=Hiragana}/u",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 1,
                    "column": 22
                }
            },
            "range": [
                0,
                22
            ],
            "regex": {
                "flags": "u",
                "pattern": "\\P{Script=Hiragana}"
            }
        }
    ]
};

==> node-espree_9.3.1~dfsg.orig.tar.xz: espree-9.3.1/tests/fixtures/ecma-version/9/regexp-unicode-property-escape/valid-negative-2.result.js <==
import conditionalRegex from "../../../../lib/conditional-regex-value.js";

export default {
    "type": "Program",
    "loc": {
        "start": {
            "line": 1,
            "column": 0
        },
        "end": {
            "line": 1,
            "column": 22
        }
    },
    "range": [
        0,
        22
    ],
    "body": [
        {
            "type": "ExpressionStatement",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 1,
                    "column": 22
                }
            },
            "range": [
                0,
                22
            ],
            "expression": conditionalRegex({
                "type": "Literal",
                "loc": {
                    "start": {
                        "line": 1,
                        "column": 0
                    },
                    "end": {
                        "line": 1,
                        "column": 22
                    }
                },
                "range": [
                    0,
                    22
                ],
                "value": null,
                "raw": "/\\P{Script=Hiragana}/u",
                "regex": {
                    "pattern": "\\P{Script=Hiragana}",
                    "flags": "u"
                }
            })
        }
    ],
    "sourceType": "script",
    "tokens": [
        {
            "type": "RegularExpression",
            "value": "/\\P{Script=Hiragana}/u",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 1,
                    "column": 22
                }
            },
            "range": [
                0,
                22
            ],
            "regex": {
                "flags": "u",
                "pattern": "\\P{Script=Hiragana}"
            }
        }
    ]
};
